.. _tutorials:

=========
Tutorials
=========
- `PySAL Package Documentation: Explanation and Comparison of Spatial Access Methods (PDF) <http://geodacenter.github.io/docs/PySALAccess%20Package_Documentation.pdf>`_
- How to Get Results for Your Own Data with the LiveApp `(PDF) <https://github.com/GeoDaCenter/GeoDaCenter.github.io/raw/main/docs/LiveAPP_Documentation.pdf>`_ and `(R code) <https://uchicago.box.com/s/676pmr9nfyx5c5g9a73gbc5kq8wqkwkd>`_
- `Generating and Contrasting Access Measures (Notebook) <https://nbviewer.jupyter.org/github/pysal/access/blob/main/notebooks/1_generating_and_plotting_access_scores.ipynb>`_
- `Package Overview (15-minute conference presentation J. Koschinsky) <https://www.youtube.com/watch?v=MshrZc_4oVY&t=1s>`_


Data Preparation
----------------
- `How to Subset Travel Cost Matricies (Notebook)  <https://nbviewer.jupyter.org/github/pysal/access/blob/main/notebooks/2_subset_travel_cost_matrices.ipynb>`_
- `How to Read, Filter, and Convert Shapefiles to .geojson (Notebook)  <https://nbviewer.jupyter.org/github/pysal/access/blob/main/notebooks/3_read_filter_convert_shapefiles_to_geojson.ipynb>`_

Implementing access
-------------------
- `How to Use access to Compute Access Scores to Resources Given XY Coordinates (Notebook)  <https://nbviewer.jupyter.org/github/pysal/access/blob/main/notebooks/4_compute_access_scores.ipynb>`_
- `How to Use access to Compute Access Scores to Resources Given XY Coordinates Snapped to Census Tract Centroids (Notebook)  <https://nbviewer.jupyter.org/github/pysal/access/blob/main/notebooks/5_compute_access_scores_joined_census_tracts.ipynb>`_
- `Building Gravity Models, Producing Composite Access Scores, and Producing Euclidean Distance Cost Matricies (Notebook)  <https://nbviewer.jupyter.org/github/pysal/access/blob/main/notebooks/1_generating_and_plotting_access_scores.ipynb>`_
